@@ -36,7 +36,7 @@ that points to the actual python object (which is stored in a session's memory o
 persisted in some fashion).
 """
 
-from typing import Any, Mapping, Optional, Callable, Union, Iterable, Iterator
+from typing import Any, Literal, Mapping, Optional, Callable, Union, Iterable, Iterator
 from inspect import Parameter
 import os
 from functools import partial
@@ -380,7 +380,7 @@ def prepare_for_crude_dispatch(
 
     >>> from inspect import signature
     >>> str(signature(crude_func))
-    '(a: str, b: str, c: int)'
+    "(a: Literal['one', 'two'], b: Literal['three', 'four'], c: int)"
 
     By default, the ``output_store`` argument is None, but if you specify a mapping
     there (or a string key that appears in the ``mall`` you specified, pointing to
@@ -394,7 +394,7 @@ def prepare_for_crude_dispatch(
     ...     output_store=output_store
     ... )
     >>> str(signature(crude_func))
-    "(a: str, b: str, c: int, save_name: str = '')"
+    "(a: Literal['one', 'two'], b: Literal['three', 'four'], c: int, save_name: str = '')"
 
     You now have this extra ``save_name`` param in your function.
     (Note that you can change its name through the ``prepare_for_crude_dispatch``'s
@@ -490,13 +490,12 @@ def prepare_for_crude_dispatch(
 
             return dict(get_values_from_stores())
 
+        outer_sig = sig.ch_annotations(
+            **{param: Literal[tuple(store)] for param, store in store_for_param.items()}
+        )
+
         ingress = Ingress(
-            inner_sig=sig,
-            kwargs_trans=kwargs_trans,
-            outer_sig=(
-                sig.ch_annotations(**{name: str for name in store_for_param})
-                # + [save_name_param]
-            ),
+            inner_sig=sig, kwargs_trans=kwargs_trans, outer_sig=outer_sig,
         )
 
     wrapped_f = wrap(func, ingress=ingress)
@@ -722,24 +721,24 @@ class Crudifier(_Crudifier):
     >>> from inspect import signature
     >>> crudified_foo = crudify(foo)
     >>> str(signature(crudified_foo))  # note how x has now a str annotation
-    '(x: str, y)'
+    "(x: Literal['stored_two'], y)"
     >>> crudified_foo('stored_two', 3)  # -> 2 + 3
     5
     >>> crudified_bar = crudify(bar)
     >>> str(signature(crudified_bar))  # note how x has now a str annotation
-    '(a, x: str)'
+    "(a, x: Literal['stored_two'])"
     >>> crudified_bar(3, 'stored_two')  # -> 3 * 2
     6
 
     If the argument names correspond to ``mall`` key, the first ``param_to_mall_map``
     argument can be specified a list of arguments, or even a space-separated string of
-    these argument names. In the following, we the ``'x y'`` is equivalent to
+    these argument names. In the following, the ``'x y'`` is equivalent to
     ``['x', 'y']``, which is equivalent to ``{'x': 'x', 'y', 'y'}``.
 
     >>> crudify = Crudifier('x y', mall={'x': {'stored_two': 2}, 'y': {'three': 3}})
     >>> f = crudify(foo)
     >>> str(signature(f))  # note that both x and y have a str annotation now
-    '(x: str, y: str)'
+    "(x: Literal['stored_two'], y: Literal['three'])"
     >>> f('stored_two', 'three')
     5
 
